"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var in_memory_storage_1 = require("./in-memory-storage");
var web_storage_config_1 = require("../web-storage.config");
var WebStorage = /** @class */ (function () {
    function WebStorage(_storageType) {
        this._storageType = _storageType;
        if (this._isSupported()) {
            this._storage = window[this._storageType];
        }
        else {
            this._storage = new in_memory_storage_1.InMemoryStorage();
        }
    }
    WebStorage.prototype.get = function (key) {
        var item = this._storage.getItem(web_storage_config_1.KeyUtility.compose(key));
        if (item === null) {
            return null;
        }
        return JSON.parse(item);
    };
    WebStorage.prototype.set = function (key, value) {
        if (!key) {
            return false;
        }
        typeof value === 'undefined' && (value = null);
        this._storage.setItem(web_storage_config_1.KeyUtility.compose(key), JSON.stringify(value));
        return true;
    };
    WebStorage.prototype.remove = function (key) {
        var fullKey = web_storage_config_1.KeyUtility.compose(key);
        if (this._storage.getItem(fullKey) === null) {
            return false;
        }
        this._storage.removeItem(fullKey);
        return true;
    };
    WebStorage.prototype.clear = function () {
        for (var key in this._storage) {
            if (web_storage_config_1.KeyUtility.isComposite(key)) {
                this._storage.removeItem(key);
            }
        }
    };
    WebStorage.prototype._isSupported = function () {
        try {
            if (this._storageType in window && window[this._storageType] !== null) {
                var webStorage = window[this._storageType];
                var key = web_storage_config_1.KeyUtility.compose('__DUMMY');
                webStorage.setItem(key, '');
                webStorage.removeItem(key);
                return true;
            }
        }
        catch (e) { }
        return false;
    };
    return WebStorage;
}());
exports.WebStorage = WebStorage;
//# sourceMappingURL=web-storage.js.map